Set renv snapshot options
yml-renv.Rdprojr_yml_renv_set sets renv snapshot options for the project.
The option controls whether renv::snapshot() is called
before and after project builds.
If the setting is not present in _projr.yml,
then the default is TRUE (renv snapshots are performed).
Arguments
- renv
logical. Whether to snapshot renv before and after builds. If
NULL, then setting is not changed. Default isNULL.- simplify_default
logical. If
TRUE, then if the setting is the same as the default (which isTRUE), then the setting is removed from_projr.yml. Default isTRUE.- profile
character. Profile to add the setting to. If
"default"(the default), the setting is added to the default profile, which is_projr.yml. IfNULL, then the active profile is used (i.e the merge of_projr-local.yml,_projr-<profile>.ymland_projr.yml) and written to_projr.yml. If another character vector, then the corresponding profile is used and written to_projr-<profile>.yml.